<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="80px"
      class="l-mes"
      :disabled="!editable"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="领料号" prop="resNo">
            <el-input
              v-model="dataForm.resNo"
              placeholder="领料号"
              readonly
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="申请日期" prop="resDate">
            <el-date-picker
              readonly
              style="width: 100%"
              v-model="moment"
              type="datetime"
              placeholder="选择日期时间"
              value-format="yyyy-MM-dd HH:mm:ss"
            >
            </el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="申请人" prop="resUser">
            <el-input
              v-model="dataForm.resUser"
              placeholder="申请人"
              readonly
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="工厂" prop="factoryId">
            <el-select
              v-model="dataForm.factoryId"
              filterable
              placeholder=""
              style="width:100%"
            >
              <el-option
                v-for="item in factoryOptions"
                :key="item.id"
                :label="item.factoryName"
                :value="item.id"
              >
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="出库类型" prop="resType">
            <el-select
              v-model="dataForm.resType"
              filterable
              placeholder="请选择出库类型"
              style="width:100%"
            >
              <el-option
                v-for="(item, index) in this.resTypeOptions"
                :label="item.stockCodeName"
                :value="item.id"
                :key="index"
              >
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <reserve-detail
      :paramObj="paramObj"
      :visible="visible"
      :disabled="dataForm.resStatus"
      ref="reserveDetail"
    >
    </reserve-detail>
    <span slot="footer" class="dialog-footer">
      <el-button
        type="primary"
        :loading="saveLoading"
        @click="dataFormSubmit(false)"
        >保存</el-button
      >
      <el-button
        type="primary"
        :loading="saveAndReturnLoading"
        @click="dataFormSubmit(true)"
        >保存并返回</el-button
      >
    </span>
  </el-dialog>
</template>

<script>
import { getObj, addObj, putObj } from '@/api/warehouse/reservemain'
import { mapGetters } from 'vuex'
import { loadStockInCode } from '../../../api/warehouse/stockincode'
import ReserveDetail from './reservedetail'
import {
  delObjReserveDetail,
  fetchReserveDetail
} from '../../../api/warehouse/reservemain'
import { loadFactoryList } from '../../../api/basic/factory'

export default {
  data() {
    return {
      paramObj: {},
      factoryOptions: [],
      addOrUpdateVisible: false,
      resTypeOptions: [],
      moment: '',
      visible: false,
      dataForm: {
        id: 0,
        resNo: '',
        resDate: '',
        resUser: '',
        factoryId: '',
        resType: '',
        resStatus: ''
      },
      dataRule: {
        resType: [
          { required: true, message: '零件编号不能为空', trigger: 'blur' }
        ],
        factoryId: [
          { required: true, message: '工厂不能为空', trigger: 'blur' }
        ]
      },
      saveLoading: false,
      saveAndReturnLoading: false
    }
  },
  computed: {
    ...mapGetters(['permissions', 'userInfo']),
    editable: function() {
      if (!this.dataForm.id) {
        return true
      }
      if (this.dataForm.id && this.dataForm.resStatus == '05create') {
        return true
      }
      return false
    }
  },
  components: {
    ReserveDetail
  },
  created() {
    this.initStockInCodeSelect()
    this.initFactorySelect()
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.paramObj.warehouseMainId = this.dataForm.id
      this.dataForm.resUser = this.userInfo.username
      this.moment = new Date()
      this.dataForm.resStatus = '05create'
      this.dataList = []
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
            this.getDataList(this.dataForm.id)
          })
        } else {
          this.$refs.tabs.currentName = '0'
        }
      })
    },
    // 获取工厂的数据
    initFactorySelect() {
      loadFactoryList().then((res) => {
        this.factoryOptions = res.data
      })
    },
    getDataList(id) {
      this.dataListLoading = true
      fetchReserveDetail(
        Object.assign({
          current: this.pageIndex,
          size: this.pageSize,
          warehouseMainId: id
        })
      ).then((response) => {
        this.dataList = response.data.data.records
        this.totalPage = response.data.data.total
      })
      this.dataListLoading = false
    },
    // 每页数
    sizeChangeHandle(val) {
      this.pageSize = val
      this.pageIndex = 1
      this.getDataList()
    },
    // 当前页
    currentChangeHandle(val) {
      this.pageIndex = val
      this.getDataList()
    },
    // 获取出入库原因码的数据
    initStockInCodeSelect() {
      loadStockInCode(
        Object.assign({
          stockCodeType: 1,
          stockCodeStatus: 1
        })
      ).then((res) => {
        this.resTypeOptions = res.data.data
      })
    },
    // 删除
    deleteHandle(id) {
      this.$confirm('是否确认删除ID为' + id, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObjReserveDetail(id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getDataList(this.dataForm.id)
        })
    },
    // 表单提交
    dataFormSubmit(status) {
      if (status) {
        this.saveAndReturnLoading = true
      } else {
        this.saveLoading = true
      }
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.$emit('refreshDataList')
              if (status) {
                this.visible = false
                this.saveAndReturnLoading = false
              } else {
                this.saveLoading = false
              }
            })
          } else {
            addObj(this.dataForm).then((response) => {
              this.$message.success('添加成功')
              this.$emit('refreshDataList')
              this.dataForm = response.data.data
              this.paramObj.warehouseMainId = this.dataForm.id
              if (status) {
                this.visible = false
                this.saveAndReturnLoading = false
              } else {
                this.saveLoading = false
              }
            })
          }
        } else {
          this.saveAndReturnLoading = false
          this.saveLoading = false
        }
      })
    }
  }
}
</script>
